==> netnrmd-3.0.0.tgz: package/changelog.md <==
﻿# 变更日志

### [v3.0.0] - 2021-06-09
- 去除 jQuery 依赖
- 新增 pangu 间隙功能
- 更新 组件依赖版本：marked@2.0.7、dompurify@2.2.9、highlight.js@11.0.1、pangu@4.0.7

### [v2.6.3] - 2021-03-16
- 优化 高度设置非全屏时有效，退出全屏设置高度生效
- 调整 storekey 参数默认值为 {location.pathname}_netnrmd_markdown
- 修复 viewmodel 参数初始化不生效
- 更新 扩展方法

### [v2.6.2] - 2021-03-13
- 更新 组件依赖版本：marked@2.0.1、dompurify@2.2.7、highlight.js@10.6.0
- 更新 工具条项支持设置样式 class

### [v2.6.1] - 2021-01-22
- 更新 组件依赖版本：marked@1.2.7、dompurify@2.2.6、highlight.js@10.5.0
- 修复 仅显示视图时某些情况出现卡死的问题

### [v2.6.0] - 2020-11-25
- 更新 组件依赖版本：marked@1.2.5、dompurify@2.2.2、highlight.js@10.4.0

### [v2.4.1] - 2020-07-18
- 修复 `Monaco Editor v0.20.0` 自适应大小无响应（延迟自适应）

### [v2.4.0] - 2020-07-17
- 修复 `Monaco Editor v0.20.0` 切换视图未自适应大小
- 调整 编辑器字体默认为 `16px`
- 更新 组件依赖：marked v1.1.1、DOMPurify v2.0.12、highlight.js v9.18.1

### [v2.2.3] - 2019-11-20
- 添加 Markdown内容自动换行

### [v2.2.2] - 2019-08-22
- 添加 扩展功能
- 添加 方法注释
- 添加 `netnrmd.render` 解析方法

### [v2.2.1] - 2019-08-17
- 修复 样式调整

### [v2.2.0] - 2019-08-17
- 调整 引用集成、功能拓展

### [v2.1.1] - 2019-08-17
- 添加 上传按钮的示例代码

### [v2.1.0] - 2019-08-16
- 添加 表情包支持，https://github.com/netnr/emoji
- 调整 去除 FontAwesome 依赖，集成SVG矢量图标到JS包
- 调整 代码着色样式改为 VS 主题色

### [v2.0.0] - 2019-08-15
- 改版：Monaco Editor 编辑器 + Marked 解析 + highlight 代码高亮

### [v1.2.0] - 2019-07-25
- 调整工具栏样式
- 调整视图切换模式
- 调整预览样式，限定图片最大高度，更好的同步滚动
- 优化自动保存
- 优化插入滚动条跳动的问题

### [v1.1.0] - 2018-12-01
- 高度设置修复
- 调整渲染样式、默认包含 `github.css` 代码高亮样式

### [v1.0.1] - 2018-06-13
- 滚动条同步方法改进
- 调整渲染样式
- 新增变化本地保存
- 隐藏工具条后高度设置修复

### [v1.0.2] - 2018-07-06
- clear方法追加清空本地缓存

==> netnrmd-3.0.2.tgz: package/changelog.md <==
﻿# 变更日志

### [v3.0.2] - 2021-11-08
- 修复 标题按钮、新增 `Ctrl+Shift+(1-6)` 快捷键

### [v3.0.1] - 2021-11-07 `弃用`
- 新增 快捷键 选中 `Alt+Y`、未选中 `Alt+N`、间隙 `Alt+S`
- 调整 快捷键 表格 `Ctrl+T` 改为 `Alt+T`
- 新增 表情 Emoji
- 更新 monaco-editor-v0.30.0 按键调整兼容
- 更新 组件依赖版本：marked-v4.0.0、dompurify-v2.3.3、highlight.js-v11.3.1

### [v3.0.0] - 2021-06-09
- 去除 jQuery 依赖
- 新增 pangu 间隙功能
- 更新 组件依赖版本：marked-v2.0.7、dompurify-v2.2.9、highlight.js-v11.0.1、pangu-v4.0.7

### [v2.6.3] - 2021-03-16
- 优化 高度设置非全屏时有效，退出全屏设置高度生效
- 调整 storekey 参数默认值为 {location.pathname}_netnrmd_markdown
- 修复 viewmodel 参数初始化不生效
- 更新 扩展方法

### [v2.6.2] - 2021-03-13
- 更新 组件依赖版本：marked-v2.0.1、dompurify-v2.2.7、highlight.js-v10.6.0
- 更新 工具条项支持设置样式 class

### [v2.6.1] - 2021-01-22
- 更新 组件依赖版本：marked-v1.2.7、dompurify-v2.2.6、highlight.js-v10.5.0
- 修复 仅显示视图时某些情况出现卡死的问题

### [v2.6.0] - 2020-11-25
- 更新 组件依赖版本：marked-v1.2.5、dompurify-v2.2.2、highlight.js-v10.4.0

### [v2.4.1] - 2020-07-18
- 修复 `Monaco Editor v0.20.0` 自适应大小无响应（延迟自适应）

### [v2.4.0] - 2020-07-17
- 修复 `Monaco Editor v0.20.0` 切换视图未自适应大小
- 调整 编辑器字体默认为 `16px`
- 更新 组件依赖：marked-v1.1.1、DOMPurify-v2.0.12、highlight.js-v9.18.1

### [v2.2.3] - 2019-11-20
- 添加 Markdown 内容自动换行

### [v2.2.2] - 2019-08-22
- 添加 扩展功能
- 添加 方法注释
- 添加 `netnrmd.render` 解析方法

### [v2.2.1] - 2019-08-17
- 修复 样式调整

### [v2.2.0] - 2019-08-17
- 调整 引用集成、功能拓展

### [v2.1.1] - 2019-08-17
- 添加 上传按钮的示例代码

### [v2.1.0] - 2019-08-16
- 添加 表情包支持
- 调整 去除 FontAwesome 依赖，集成 SVG 矢量图标到 JS 包
- 调整 代码着色样式改为 VS 主题色

### [v2.0.0] - 2019-08-15
- 改版：Monaco Editor 编辑器 + Marked 解析 + highlight 代码高亮

### [v1.2.0] - 2019-07-25
- 调整工具栏样式
- 调整视图切换模式
- 调整预览样式，限定图片最大高度，更好的同步滚动
- 优化自动保存
- 优化插入滚动条跳动的问题

### [v1.1.0] - 2018-12-01
- 高度设置修复
- 调整渲染样式、默认包含 `github.css` 代码高亮样式

### [v1.0.1] - 2018-06-13
- 滚动条同步方法改进
- 调整渲染样式
- 新增变化本地保存
- 隐藏工具条后高度设置修复

### [v1.0.2] - 2018-07-06
- clear 方法追加清空本地缓存
